@@ -71,7 +71,7 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
 	params->state_type    = (ClearlooksStateType)state_type;
 	params->corners       = CR_CORNER_ALL;
 	params->ltr           = ge_widget_is_ltr ((GtkWidget*)widget);
-	params->focus         = widget && GTK_WIDGET_HAS_FOCUS (widget);
+	params->focus         = !CLEARLOOKS_STYLE (style)->disable_focus && widget && GTK_WIDGET_HAS_FOCUS (widget);
 	params->is_default    = widget && GE_WIDGET_HAS_DEFAULT (widget);
 	params->enable_shadow = FALSE;
 	params->radius        = CLEARLOOKS_STYLE (style)->radius;
@@ -133,6 +133,25 @@ clearlooks_style_draw_flat_box (DRAW_ARGS)
 
 		cairo_destroy (cr);
 	}
+	else if (DETAIL ("icon_view_item"))
+	{
+		WidgetParameters params;
+		ClearlooksStyle  *clearlooks_style;
+		ClearlooksColors *colors;
+		cairo_t          *cr;
+
+		CHECK_ARGS
+		SANITIZE_SIZE
+
+		clearlooks_style = CLEARLOOKS_STYLE (style);
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		colors = &clearlooks_style->colors;
+		cr = ge_gdk_drawable_to_cairo (window, area);
+
+		STYLE_FUNCTION (draw_icon_view_item) (cr, colors, &params, x, y, width, height);
+
+		cairo_destroy (cr);
+	}
 	else if ((CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY || CLEARLOOKS_STYLE (style)->style == CL_STYLE_GUMMY) &&
 	         ((DETAIL("checkbutton") || DETAIL("radiobutton")) && state_type == GTK_STATE_PRELIGHT))
 	{
@@ -537,8 +556,16 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		STYLE_FUNCTION(draw_list_view_header) (cr, colors, &params, &header,
 		                                       x, y, width, height);
 	}
-	else if (DETAIL ("button") || DETAIL ("buttondefault"))
+	else if (DETAIL ("buttondefault"))
 	{
+		/* We are already checking the default button with the
+		 * "clearlooks_set_widget_parameters" function, so we may occur
+		 * in drawing the button two times. Let's return then.
+		 */
+	}
+	else if (DETAIL ("button"))
+	{
+	
 		WidgetParameters params;
 		ShadowParameters shadow = { CR_CORNER_ALL, CL_SHADOW_NONE } ;
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
@@ -1321,6 +1348,7 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 	clearlooks_style->colorize_scrollbar  = CLEARLOOKS_RC_STYLE (rc_style)->colorize_scrollbar;
 	clearlooks_style->animation           = CLEARLOOKS_RC_STYLE (rc_style)->animation;
 	clearlooks_style->radius              = CLAMP (CLEARLOOKS_RC_STYLE (rc_style)->radius, 0.0, 10.0);
+	clearlooks_style->disable_focus       = CLEARLOOKS_RC_STYLE (rc_style)->disable_focus;
 
 	if (clearlooks_style->has_focus_color)
 		clearlooks_style->focus_color     = CLEARLOOKS_RC_STYLE (rc_style)->focus_color;
@@ -1393,6 +1421,10 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	CHECK_ARGS
 	SANITIZE_SIZE
 
+	/* Just return if focus drawing is disabled. */
+	if (clearlooks_style->disable_focus)
+		return;
+
 	cr = gdk_cairo_create (window);
 
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
@@ -1524,6 +1556,10 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	{
 		focus.type = CL_FOCUS_TREEVIEW; /* Treeview without content is focused. */
 	}
+	else if (DETAIL("icon_view"))
+	{
+		focus.type = CL_FOCUS_ICONVIEW;
+	}
 	else
 	{
 		focus.type = CL_FOCUS_UNKNOWN; /* Custom widgets (Beagle) and something unknown */
@@ -1563,6 +1599,7 @@ clearlooks_style_copy (GtkStyle * style, GtkStyle * src)
 	cl_style->animation           = cl_src->animation;
 	cl_style->radius              = cl_src->radius;
 	cl_style->style               = cl_src->style;
+	cl_style->disable_focus       = cl_src->disable_focus;
 
 	GTK_STYLE_CLASS (clearlooks_style_parent_class)->copy (style, src);
 }
