@@ -1,6 +1,7 @@
 /* Industrial Engine
  * Copyright (C) 2001 Red Hat, Inc.
  * Copyright (C) 2002 Ximian, Inc.
+ * Copyright (C) 2006 Benjamin Berg
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,15 +21,16 @@
  * Written by Owen Taylor <otaylor@redhat.com>
  * modified by Alexander Larsson <alexl@redhat.com>
  * modified by Christopher Lahey <clahey@ximian.com>
+ * modified by Benjamin Berg <benjamin@sipsolutions.net>
  */
 #include <gtk/gtkstyle.h>
 
+#include "ge-support.h"
+
 typedef struct _IndustrialStyle IndustrialStyle;
 typedef struct _IndustrialStyleClass IndustrialStyleClass;
 
-extern GType industrial_type_style G_GNUC_INTERNAL;
-
-#define INDUSTRIAL_TYPE_STYLE              industrial_type_style
+#define INDUSTRIAL_TYPE_STYLE              (industrial_style_get_type ())
 #define INDUSTRIAL_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), INDUSTRIAL_TYPE_STYLE, IndustrialStyle))
 #define INDUSTRIAL_STYLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), INDUSTRIAL_TYPE_STYLE, IndustrialStyleClass))
 #define INDUSTRIAL_IS_STYLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), INDUSTRIAL_TYPE_STYLE))
@@ -39,12 +41,14 @@ struct _IndustrialStyle {
 	GtkStyle parent_instance;
 
 	double contrast;
-	double contrast_center;
 	gboolean rounded_buttons;
+	GQuark hint;
 };
 
 struct _IndustrialStyleClass {
 	GtkStyleClass parent_class;
 };
 
-void industrial_style_register_type (GTypeModule * module) G_GNUC_INTERNAL;
+GE_INTERNAL void industrial_style_register_types (GTypeModule * module);
+GE_INTERNAL GType industrial_style_get_type      (void);
+
