@@ -3,7 +3,7 @@ enum {
 	TOKEN_CONTRAST = G_TOKEN_LAST + 1,
 	TOKEN_CONTRAST_CENTER,
 	TOKEN_ROUNDED_BUTTONS,
-	TOKEN_WIDE,
+	TOKEN_HINT,
 	TOKEN_TRUE,
 	TOKEN_FALSE
 };
@@ -14,6 +14,7 @@ static struct {
 } theme_symbols[] = {
 	{ "contrast",		TOKEN_CONTRAST },
 	{ "rounded_buttons",	TOKEN_ROUNDED_BUTTONS },
+	{ "hint",               TOKEN_HINT },
 	{ "TRUE",		TOKEN_TRUE },
 	{ "FALSE",		TOKEN_FALSE }
 };
@@ -42,7 +43,7 @@ theme_parse_named_double (GScanner * scanner, double *value)
 	return G_TOKEN_NONE;
 }
 
-static gboolean
+static guint
 theme_parse_boolean (GScanner * scanner,
 		     GTokenType wanted_token, gboolean * retval)
 {
@@ -92,11 +93,9 @@ parse_rc_style (GScanner * scanner,
 	 */
 
 	if (!g_scanner_lookup_symbol (scanner, theme_symbols[0].name)) {
-		g_scanner_freeze_symbol_table (scanner);
 		for (i = 0; i < G_N_ELEMENTS (theme_symbols); i++)
 			g_scanner_scope_add_symbol (scanner, scope_id, theme_symbols[i].name,
 						    GINT_TO_POINTER (theme_symbols[i].token));
-		g_scanner_thaw_symbol_table (scanner);
 	}
 
 	/* We're ready to go, now parse the top level */
@@ -112,6 +111,10 @@ parse_rc_style (GScanner * scanner,
 			token = theme_parse_boolean (scanner, TOKEN_ROUNDED_BUTTONS, &rc->rounded_buttons);
 			rc->fields |= INDUSTRIAL_FIELDS_ROUNDED_BUTTONS;
 			break;
+		case TOKEN_HINT:
+			token = ge_rc_parse_hint (scanner, &rc->hint);
+			rc->fields |= INDUSTRIAL_FIELDS_HINT;
+			break;
 		default:
 			g_scanner_get_next_token (scanner);
 			token = G_TOKEN_RIGHT_CURLY;
