@@ -4,9 +4,7 @@
 typedef struct _ThiniceStyle ThiniceStyle;
 typedef struct _ThiniceStyleClass ThiniceStyleClass;
 
-extern GType thinice_type_style;
-
-#define THINICE_TYPE_STYLE              thinice_type_style
+#define THINICE_TYPE_STYLE              (thinice_style_get_type ())
 #define THINICE_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), THINICE_TYPE_STYLE, ThiniceStyle))
 #define THINICE_STYLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), THINICE_TYPE_STYLE, ThiniceStyleClass))
 #define THINICE_IS_STYLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), THINICE_TYPE_STYLE))
@@ -24,6 +22,7 @@ struct _ThiniceStyleClass
   GtkStyleClass parent_class;
 };
 
-void thinice_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
+GE_INTERNAL void  thinice_style_register_types (GTypeModule *module);
+GE_INTERNAL GType thinice_style_get_type       (void);
 
 
